@@ -1,4 +1,6 @@
-mloop <- function(cx=0,cy=0,retention=0.2,b.x=0.6,b.y=0.8,n=1,m=1,sd.x=0,sd.y=0,phase.angle=0,n.points=24,period=24,extended.classical=FALSE,seed=NULL) {
+mloop <- function(cx=0,cy=0,retention=0.2,b.x=0.6,b.y=0.8,n=1,m=1,sd.x=0,sd.y=0,
+                  phase.angle=0,n.points=24,period=24,extended.classical=FALSE,
+                  seed=NULL) {
  if (!is.null(seed)) set.seed(seed)
  if (extended.classical==FALSE) {
   x<-cx+b.x*cos((1:n.points)/period*2*pi+phase.angle/180*pi)+rnorm(n.points,0,sd.x)
